changeset 30750:e96da8e19cef

(enum event_kind): New member multibyte_char_keystroke.
author Kenichi Handa <handa@m17n.org>
date Fri, 11 Aug 2000 00:51:25 +0000
parents 7a0d5d24269e
children c10a26933929
files src/termhooks.h
diffstat 1 files changed, 8 insertions(+), 1 deletions(-) [+]
line wrap: on
line diff
--- a/src/termhooks.h	Fri Aug 11 00:50:51 2000 +0000
+++ b/src/termhooks.h	Fri Aug 11 00:51:25 2000 +0000
@@ -215,6 +215,12 @@
 				   which the key was typed.
 				   .timestamp gives a timestamp (in
 				   milliseconds) for the keystroke.  */
+  multibyte_char_keystroke,	/* The multibye char code is in .code,
+				   perhaps with modifiers applied.
+				   The others are the same as
+				   ascii_keystroke.  This type of event
+				   is generated only when we are using
+				   XIM on X window.  */
   non_ascii_keystroke,		/* .code is a number identifying the
 				   function key.  A code N represents
 				   a key whose name is
@@ -337,7 +343,8 @@
   /* What kind of event was this?  */
   int kind;
   
-  /* For an ascii_keystroke, this is the character.
+  /* For an ascii_keystroke and multibyte_char_keystroke, this is the
+     character.
      For a non_ascii_keystroke, this is the keysym code.
      For a mouse event, this is the button number.  */
   /* In WindowsNT, for a mouse wheel event, this is the delta.  */